==> greekromanutils-1.0.0.tar.gz: greekromanutils-1.0.0/GreekRomanUtils/DataStorage/Alphabet.py <==
class GreekAlphabet:
    GREEK_ALPHABET_DICT = {
        'α': 'alpha', 'β': 'beta', 'γ': 'gamma', 'δ': 'delta', 'ε': 'epsilon',
        'ζ': 'zeta', 'η': 'eta', 'θ': 'theta', 'ι': 'iota', 'κ': 'kappa',
        'λ': 'lambda', 'μ': 'mu', 'ν': 'nu', 'ξ': 'xi', 'ο': 'omicron',
        'π': 'pi', 'ρ': 'rho', 'σ': 'sigma', 'τ': 'tau', 'υ': 'upsilon',
        'φ': 'phi', 'χ': 'chi', 'ψ': 'psi', 'ω': 'omega', 'Ϝ': 'digamma',
        '_': 'underscape', '~': 'macron'
    }
    GREEK_ALPHABET_DICT_CAPITAL = {
        'Α': 'Alpha', 'Β': 'Beta', 'Γ': 'Gamma', 'Δ': 'Delta', 'Ε': 'Epsilon',
        'Ζ': 'Zeta', 'Η': 'Eta', 'Θ': 'Theta', 'Ι': 'Iota', 'Κ': 'Kappa',
        'Λ': 'Lambda', 'Μ': 'Mu', 'Ν': 'Nu', 'Ξ': 'Xi', 'Ο': 'Omicron',
        'Π': 'Pi', 'Ρ': 'Rho', 'Σ': 'Sigma', 'Τ': 'Tau', 'Υ': 'Upsilon',
        'Φ': 'Phi', 'Χ': 'Chi', 'Ψ': 'Psi', 'Ω': 'Omega', 'Ϝ': 'Digamma',
        '_': 'Underscape', '~': 'Macron'
    }
    GREEK_NUMERAL_LIST = [
        ("α", 1), ("β", 2), ("γ", 3),
        ("δ", 4), ("ε", 5), ("Ϝ", 6),
        ("ζ", 7), ("η", 8), ("θ", 9),
        ("ι", 10), ("κ", 20), ("λ", 30),
        ("μ", 40), ("ν", 50), ("ξ", 60),
        ("ο", 70), ("π", 80), ("ϙ", 90),
        ("ρ", 100), ("σ", 200), ("τ", 300),
        ("υ", 400), ("φ", 500), ("χ", 600),
        ("ψ", 700), ("ω", 800), ("ϡ", 900)
    ]
    GREEK_NUMERAL_LIST_CAPITAL = [
        ("Α", 1), ("Β", 2), ("Γ", 3),
        ("Δ", 4), ("Ε", 5), ("Ϝ", 6),
        ("Ζ", 7), ("Η", 8), ("Θ", 9),
        ("Ι", 10), ("Κ", 20), ("Λ", 30),
        ("Μ", 40), ("Ν", 50), ("Ξ", 60),
        ("Ο", 70), ("Π", 80), ("Ϙ", 90),
        ("Ρ", 100), ("Σ", 200), ("Τ", 300),
        ("Υ", 400), ("Φ", 500), ("Χ", 600),
        ("Ψ", 700), ("Ω", 800), ("Ϡ", 900)
    ]
    GREEK_NUMERAL_DICT = {
        "α": 1, "β": 2, "γ": 3,
        "δ": 4, "ε": 5, "Ϝ": 6,
        "ζ": 7, "η": 8, "θ": 9,
        "ι": 10, "κ": 20, "λ": 30,
        "μ": 40, "ν": 50, "ξ": 60,
        "ο": 70, "π": 80, "ϙ": 90,
        "ρ": 100, "σ": 200, "τ": 300,
        "υ": 400, "φ": 500, "χ": 600,
        "ψ": 700, "ω": 800, "ϡ": 900
    }
    GREEK_NUMERAL_DICT_CAPITAL = {
        "Α": 1, "Β": 2, "Γ": 3,
        "Δ": 4, "Ε": 5, "Ϝ": 6,
        "Ζ": 7, "Η": 8, "Θ": 9,
        "Ι": 10, "Κ": 20, "Λ": 30,
        "Μ": 40, "Ν": 50, "Ξ": 60,
        "Ο": 70, "Π": 80, "Ϙ": 90,
        "Ρ": 100, "Σ": 200, "Τ": 300,
        "Υ": 400, "Φ": 500, "Χ": 600,
        "Ψ": 700, "Ω": 800, "Ϡ": 900
    }

class RomanNumberAlphabet:
    ROMAN_NUMERAL_LIST = [
        ("~M", 1000000), ("~D", 500000), ("~C", 100000),
        ("~L", 50000), ("~X", 10000), ("~V", 5000),  # "~" indicates a Macron
        ("M", 1000), ("CM", 900), ("D", 500),
        ("CD", 400), ("C", 100),  ("XC", 90),
        ("L", 50),   ("XL", 40),  ("X", 10),
        ("IX", 9),   ("V", 5),    ("IV", 4),
        ("I", 1)
    ]
    ROMAN_NUMERAL_DICT = {
        "~M": 1000000, "~D": 500000, "~C": 100000,
        "~L": 50000, "~X": 10000, "~V": 5000,  # "~" indicates a Macron
        "M": 1000, "CM": 900, "D": 500,
        "CD": 400, "C": 100,  "XC": 90,
        "L": 50,   "XL": 40,  "X": 10,
        "IX": 9,   "V": 5,    "IV": 4,
        "I": 1
    }

==> greekromanutils-1.0.3.tar.gz: greekromanutils-1.0.3/GreekRomanUtils/DataStorage/Alphabet.py <==
class GreekAlphabet:
    GREEK_ALPHABET_DICT = {
        'α': 'alpha', 'β': 'beta', 'γ': 'gamma', 'δ': 'delta', 'ε': 'epsilon',
        'ζ': 'zeta', 'η': 'eta', 'θ': 'theta', 'ι': 'iota', 'κ': 'kappa',
        'λ': 'lambda', 'μ': 'mu', 'ν': 'nu', 'ξ': 'xi', 'ο': 'omicron',
        'π': 'pi', "ϙ": 'koppa', 'ρ': 'rho', 'σ': 'sigma', 'τ': 'tau', 'υ': 'upsilon',
        'φ': 'phi', 'χ': 'chi', 'ψ': 'psi', 'ω': 'omega', 'ϝ': 'digamma', "ϡ": 'Sampi',
        '_': 'underscape', '~': 'macron'
    }
    GREEK_ALPHABET_DICT_CAPITAL = {
        'Α': 'Alpha', 'Β': 'Beta', 'Γ': 'Gamma', 'Δ': 'Delta', 'Ε': 'Epsilon',
        'Ζ': 'Zeta', 'Η': 'Eta', 'Θ': 'Theta', 'Ι': 'Iota', 'Κ': 'Kappa',
        'Λ': 'Lambda', 'Μ': 'Mu', 'Ν': 'Nu', 'Ξ': 'Xi', 'Ο': 'Omicron',
        'Π': 'Pi', 'Ϙ': 'Koppa', 'Ρ': 'Rho', 'Σ': 'Sigma', 'Τ': 'Tau', 'Υ': 'Upsilon',
        'Φ': 'Phi', 'Χ': 'Chi', 'Ψ': 'Psi', 'Ω': 'Omega', 'Ϝ': 'Digamma', "Ϡ": 'Sampi',
        '_': 'Underscape', '~': 'Macron'
    }
    GREEK_NUMERAL_LIST = [
        ("α", 1), ("β", 2), ("γ", 3),
        ("δ", 4), ("ε", 5), ("ϝ", 6),
        ("ζ", 7), ("η", 8), ("θ", 9),
        ("ι", 10), ("κ", 20), ("λ", 30),
        ("μ", 40), ("ν", 50), ("ξ", 60),
        ("ο", 70), ("π", 80), ("ϙ", 90),
        ("ρ", 100), ("σ", 200), ("τ", 300),
        ("υ", 400), ("φ", 500), ("χ", 600),
        ("ψ", 700), ("ω", 800), ("ϡ", 900)
    ]
    GREEK_NUMERAL_LIST_CAPITAL = [
        ("Α", 1), ("Β", 2), ("Γ", 3),
        ("Δ", 4), ("Ε", 5), ("Ϝ", 6),
        ("Ζ", 7), ("Η", 8), ("Θ", 9),
        ("Ι", 10), ("Κ", 20), ("Λ", 30),
        ("Μ", 40), ("Ν", 50), ("Ξ", 60),
        ("Ο", 70), ("Π", 80), ("Ϙ", 90),
        ("Ρ", 100), ("Σ", 200), ("Τ", 300),
        ("Υ", 400), ("Φ", 500), ("Χ", 600),
        ("Ψ", 700), ("Ω", 800), ("Ϡ", 900)
    ]
    GREEK_NUMERAL_DICT = {
        "α": 1, "β": 2, "γ": 3,
        "δ": 4, "ε": 5, "ϝ": 6,
        "ζ": 7, "η": 8, "θ": 9,
        "ι": 10, "κ": 20, "λ": 30,
        "μ": 40, "ν": 50, "ξ": 60,
        "ο": 70, "π": 80, "ϙ": 90,
        "ρ": 100, "σ": 200, "τ": 300,
        "υ": 400, "φ": 500, "χ": 600,
        "ψ": 700, "ω": 800, "ϡ": 900
    }
    GREEK_NUMERAL_DICT_CAPITAL = {
        "Α": 1, "Β": 2, "Γ": 3,
        "Δ": 4, "Ε": 5, "Ϝ": 6,
        "Ζ": 7, "Η": 8, "Θ": 9,
        "Ι": 10, "Κ": 20, "Λ": 30,
        "Μ": 40, "Ν": 50, "Ξ": 60,
        "Ο": 70, "Π": 80, "Ϙ": 90,
        "Ρ": 100, "Σ": 200, "Τ": 300,
        "Υ": 400, "Φ": 500, "Χ": 600,
        "Ψ": 700, "Ω": 800, "Ϡ": 900
    }

class RomanNumberAlphabet:
    ROMAN_NUMERAL_LIST = [
        ("~M", 1000000), ("~D", 500000), ("~C", 100000),
        ("~L", 50000), ("~X", 10000), ("~V", 5000),  # "~" indicates a Macron
        ("M", 1000), ("CM", 900), ("D", 500),
        ("CD", 400), ("C", 100),  ("XC", 90),
        ("L", 50),   ("XL", 40),  ("X", 10),
        ("IX", 9),   ("V", 5),    ("IV", 4),
        ("I", 1)
    ]
    ROMAN_NUMERAL_DICT = {
        "~M": 1000000, "~D": 500000, "~C": 100000,
        "~L": 50000, "~X": 10000, "~V": 5000,  # "~" indicates a Macron
        "M": 1000, "CM": 900, "D": 500,
        "CD": 400, "C": 100,  "XC": 90,
        "L": 50,   "XL": 40,  "X": 10,
        "IX": 9,   "V": 5,    "IV": 4,
        "I": 1
    }
